#!/bin/ksh
###############################################################################
# Licensed Materials - Property of IBM
# 5724-T40 IBM License Metric Tool
# 5724-S94 IBM Tivoli Asset Discovery for Distributed
#
# (C) Copyright IBM Corp. 2004, 2011.  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
###############################################################################

dir_path=$1
force=$2

# ***************************************************************
# CONFIGURATION SECTION
# ***************************************************************
IF_version=IF2
current_version=7.2.2.1
IF_marker_file=7221_IF2.dat
db_script_filename=migrate_7.2.2.12.sql
if_update_agents=false
if_update_UI_classes=false
backup_dir=7.2.2.12_backup_`date +%Y%m%d_%H%M`
jars=jars
selfupdate=selfupdate
data=data #self update data folder
properties=properties #self update properties folder
UI_classes=UI_classes #folder name in backup for UI classes
zerog_registry_file="/var/.com.zerog.registry.xml"
# ***************************************************************

print_usage()
{
  echo "Use the InterimFix installer using the following params:"
  echo "   install.sh [<ILMT|TAD4D-install-dir>] [force]"
}

#Checking whether .com.zerog.registry.xml file exists if force was not used
if [[ "$force" != "force" ]]
then
  if [[ -f "$zerog_registry_file" ]]
  then
    echo "SUCCESS: Install Anywhere registry file found."
  else
    echo "Error: Required Install Anywhere registry file ($zerog_registry_file) is missing, cannot locate product directory."
    print_usage
    exit 1
  fi
fi


#Checking if the LMT directory was provided, if not pulls it from the registry file
if [ -n "$dir_path" ]
then
  echo "Using ILMT/TAD4D install location: "$dir_path
else 	
  dir_path=`cat $zerog_registry_file | grep '<product' | grep 'IBM License Metric Tool' | sed 's/.*location=\"//' | sed 's/\".*//'`
  if [[ -z "$dir_path" ]]
  then
    dir_path=`cat $zerog_registry_file | grep '<product' | grep 'IBM Tivoli Asset Discovery for Distributed' | sed 's/.*location=\"//' | sed 's/\".*//'`
  fi
  echo "ILMT/TAD4D install directory read from reqistry file: $dir_path"
fi

#Checking if the LMT directory exists
if [ ! -d "$dir_path" ]
then
  echo "Error: The ILMT/TAD4D directory ($dir_path) does not exists."
  print_usage 
  exit 1
else
  backup_dir=$dir_path"/"$backup_dir
fi


#Checking the software version in registry file (if the force was not used)
if [[ "$force" == "force" ]]
then
  echo "Force option used - not checking the currently installed product version."
else  
  version=`cat $zerog_registry_file | grep '<product' | grep 'IBM License Metric Tool' | sed 's/.*version=\"//' | sed 's/\".*//'`
  if [[ -z "$version" ]]
  then
    version=`cat $zerog_registry_file | grep '<product' | grep 'IBM Tivoli Asset Discovery for Distributed' | sed 's/.*version=\"//' | sed 's/\".*//'`
  fi
  if [[ "$version" != "$current_version" ]]
  then
    echo "Error: Unsupported product version ($version), it needs to be ILMT/TAD4D $current_version"
    exit 1
  else
	echo "Currently installed product version: $version"
  fi
fi

#if the Interim fix was already installed
fix_file=$dir_path"/$IF_marker_file"
if [[ -f "$fix_file" && "$force" != "force" ]]
then
	echo "Error: Interim Fix $current_version $IF_version is already installed."
	exit 1
fi


#Checking whether it is ILMT or TAD4D installation
lmt_war_path=$dir_path"/eWAS/systemApps/isclite.ear/lmt_admin.war"
tad4d_war_path=$dir_path"/eWAS/systemApps/isclite.ear/tad4d_admin.war"
admin_libdir=$dir_path"/eWAS/systemApps/isclite.ear/lmt_admin.war/WEB-INF/lib/"
UI_classes__dir=$dir_path"/eWAS/systemApps/isclite.ear/lmt_admin.war/WEB-INF/classes/com/ibm/license/mgmt/ui/"
msghandler_libdir=$dir_path"/eWAS/profiles/AppSrv01/installedApps/cell1/LMT-TAD4D_Agent_message_handler.ear/com.ibm.license.mgmt.msghandler.web.war/WEB-INF/lib/"
selfupdate_properties_path=$dir_path"/eWAS/profiles/AppSrv01/installedApps/cell1/LMT-TAD4D_Agent_message_handler.ear/com.ibm.license.mgmt.msghandler.web.war/WEB-INF/conf/selfupdate/"
selfupdate_data_path=$dir_path"/eWAS/profiles/AppSrv01/installedApps/cell1/LMT-TAD4D_Agent_message_handler.ear/com.ibm.license.mgmt.msghandler.web.war/webdoc/agent/selfupdate/"

if [ -d "$lmt_war_path" ]
then
	echo "ILMT installation was found."
else
	if [ -d "$tad4d_war_path" ]
	then
		echo "TAD4D installation was found."
		admin_libdir=$dir_path"/eWAS/systemApps/isclite.ear/tad4d_admin.war/WEB-INF/lib/"
		UI_classes__dir=$dir_path"/eWAS/systemApps/isclite.ear/tad4d_admin.war/WEB-INF/classes/com/ibm/license/mgmt/ui/"
	else
		echo "Error: Cannot locate the product directories, check whether the provided product install dir is correct."
		print_usage
		exit 1
	fi
fi

#Checking whether lib directories exists
if [[ ! ( -d "$admin_libdir" && -d "$msghandler_libdir") ]]
then
	echo "Error: the msghandler or admin server lib directory cannot be located."
	exit 1
fi

if $if_update_agents
then
	if [[ ! ( -d "$selfupdate_properties_path" && -d "$selfupdate_data_path" ) ]]
	then
		echo "Error: the agent self updates directories cannot be located."
		exit 1
	fi
fi

if $if_update_UI_classes
then
	if [[ ! -d "$UI_classes__dir" ]]
	then
		echo "Error: the UI classes directories cannot be located."
		exit 1
	fi
fi

#Stopping the server
srvstop=$dir_path"/cli/srvstop.sh"
if [ -f "$srvstop" ]
then
	echo "Stopping the server ..."
	$srvstop
	return_code=$?	
	if [[ $return_code -eq 0 || $return_code -eq 246 ]]
	then
		echo "Server stopped successfully."
	else
		echo "Error: Some problems occur during stopping the server."
		echo "Try to stop the application server manually and try again."
		exit 1
	fi
else
	echo "Error: Cannot find srvstop.sh script to stop the server."
	exit 1
fi

#BACKUP
echo "Creating backup files in "$backup_dir" directory"
rm -rf $backup_dir
mkdir $backup_dir
if [ $? -ne 0 ]
then
	echo "Error: Cannot create the backup directory."
	exit 1
fi

mkdir $backup_dir/$jars
if [ $? -ne 0 ]
then
	echo "Error: Cannot create the $backup_dir/$jars directory."
	exit 1
fi

if $if_update_agents
then
	mkdir $backup_dir/$selfupdate
	if [ $? -ne 0 ]
	then
		echo "Error: Cannot create the $backup_dir/$selfupdate directory."
		exit 1
	fi

	mkdir $backup_dir/$selfupdate/$data
	if [ $? -ne 0 ]
	then
		echo "Error: Cannot create the $backup_dir/$selfupdate/$data directory."
		exit 1
	fi

	mkdir $backup_dir/$selfupdate/$properties
	if [ $? -ne 0 ]
	then
		echo "Error: Cannot create the $backup_dir/$selfupdate/$properties directory."
		exit 1
	fi
fi

if $if_update_UI_classes
then
	mkdir $backup_dir/$UI_classes
	if [ $? -ne 0 ]
	then
		echo "Error: Cannot create the $backup_dir/$UI_classes directory."
		exit 1
	fi
fi

for file in $admin_libdir"com.ibm.license.mgmt.*"
do
	cp $file $backup_dir/$jars/
done

for file in $msghandler_libdir"com.ibm.license.mgmt.msghandler.*"
do
	cp $file $backup_dir/$jars/
done

if $if_update_agents
then
	cp $selfupdate_properties_path"agent_packages.properties" $backup_dir/$selfupdate/$properties/
	cp $selfupdate_data_path* $backup_dir/$selfupdate/$data/
fi

if $if_update_UI_classes
then
	cp -rf $UI_classes__dir* $backup_dir/$UI_classes/
fi
	
#INSTALLATION
echo "Replacing the files"

cp -f ./$jars/com.ibm.license.mgmt.admin.aggregation.jar $admin_libdir
cp -f ./$jars/com.ibm.license.mgmt.admin.catalog.jar $admin_libdir
cp -f ./$jars/com.ibm.license.mgmt.admin.inventory.builder.jar $admin_libdir
cp -f ./$jars/com.ibm.license.mgmt.admin.periodictasks.jar $admin_libdir
cp -f ./$jars/com.ibm.license.mgmt.admin.web.jar $admin_libdir
cp -f ./$jars/com.ibm.license.mgmt.bl.jar $admin_libdir
cp -f ./$jars/com.ibm.license.mgmt.catalog.importer.jar $admin_libdir
cp -f ./$jars/com.ibm.license.mgmt.configmgr.jar $admin_libdir
cp -f ./$jars/com.ibm.license.mgmt.core.jar $admin_libdir
cp -f ./$jars/com.ibm.license.mgmt.dao.jar $admin_libdir
cp -f ./$jars/com.ibm.license.mgmt.encryption.jar $admin_libdir
cp -f ./$jars/com.ibm.license.mgmt.hwinfo.jar $admin_libdir
cp -f ./$jars/com.ibm.license.mgmt.msgandtrace.jar $admin_libdir
cp -f ./$jars/com.ibm.license.mgmt.srvfrontend.jar $admin_libdir
cp -f ./$jars/com.ibm.license.mgmt.topologymgr.jar $admin_libdir
cp -f ./$jars/com.ibm.license.mgmt.util.jar $admin_libdir
cp -f ./$jars/com.ibm.license.mgmt.vmmanager.jar $admin_libdir
cp -f ./$jars/com.ibm.license.mgmt.ws.serialization.jar $admin_libdir

cp -f ./$jars/com.ibm.license.mgmt.bl.jar $msghandler_libdir
cp -f ./$jars/com.ibm.license.mgmt.configmgr.jar $msghandler_libdir
cp -f ./$jars/com.ibm.license.mgmt.core.jar $msghandler_libdir
cp -f ./$jars/com.ibm.license.mgmt.dao.jar $msghandler_libdir
cp -f ./$jars/com.ibm.license.mgmt.encryption.jar $msghandler_libdir
cp -f ./$jars/com.ibm.license.mgmt.hwinfo.jar $msghandler_libdir
cp -f ./$jars/com.ibm.license.mgmt.msgandtrace.jar $msghandler_libdir
cp -f ./$jars/com.ibm.license.mgmt.msghandler.core.jar $msghandler_libdir
cp -f ./$jars/com.ibm.license.mgmt.msghandler.web.jar $msghandler_libdir
cp -f ./$jars/com.ibm.license.mgmt.srvfrontend.jar $msghandler_libdir
cp -f ./$jars/com.ibm.license.mgmt.util.jar $msghandler_libdir

if $if_update_agents
then
	cp -f ./$selfupdate/$properties/agent_packages.properties $selfupdate_properties_path
	rm -f $selfupdate_data_path*
	cp -f ./$selfupdate/$data/* $selfupdate_data_path
fi

if $if_update_UI_classes
then
	cp -rf ./$UI_classes/* $UI_classes__dir
fi

echo "All files replaced"

#MARKER FILE
echo "Creating a $current_version $IF_version Interim Fix file."
echo "$current_version $IF_version" > $fix_file

echo ""
echo "Replacing files for ILMT/TAD4D $current_version $IF_version Interim Fix ended SUCCESSFULLY."
echo "ILMT/TAD4D server is now stopped since additional, manual action is still needed."
echo "Please go to the machine where TLMA DB is placed and run the SQL script $db_script_filename"
echo "which comes with the Interim Fix. To do this execute the following DB2 command:"
echo "                     db2 -vf $db_script_filename -td%"
echo "Once this task is completed, please start the ILMT/TAD4D server to finish Interim Fix application."

exit 0
